<?php
/**
 * Custom and output functions for the theme customizer 
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'shopy_mod' ) ) :
/**
 * Wrap get_theme_mod function
 */
function shopy_mod( $name ) {

	// Theme prefix
	$prefix = 'shopy-';

	// Allow to filter the customizer.
	return apply_filters( 'shopy_mod', get_theme_mod( $name, customizer_library_get_default( $name ) ), $prefix, $name );

}
endif;

if ( ! function_exists( 'shopy_sanitize_fontawesome_tag' ) ) :
/**
 * Sanitize a input text for fontawesome.
 *
 * @since  1.0.0
 */
function shopy_sanitize_fontawesome_tag( $string ) {
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	return $string;
}
endif;

/**
 * Custom customizer function.
 *
 * @since  1.0.0
 */
function shopy_move_default_customizer( $wp_customize ) {

	// Move the customize to new panel
	$wp_customize->get_section( 'title_tagline' )->panel       = 'header';
	$wp_customize->get_section( 'static_front_page' )->panel   = 'general';
	$wp_customize->get_section( 'colors' )->panel              = 'color';
	$wp_customize->get_section( 'background_image' )->panel    = 'bg_image';

	// Change the title/description
	$wp_customize->get_section( 'title_tagline' )->title       = __( 'Site Title', 'shopy' );
	$wp_customize->get_section( 'title_tagline' )->description = __( 'Site title will automatically disapear if you upload a logo.', 'shopy' );
	$wp_customize->get_section( 'colors' )->title              = __( 'Background', 'shopy' );
	$wp_customize->get_section( 'colors' )->priority           = 1;

	// Live preview
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';

}
add_action( 'customize_register', 'shopy_move_default_customizer' );

/**
 * Retrieve tags list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function shopy_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = __( 'Select a tag &hellip;', 'shopy' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Retrieve categories list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function shopy_cats_list() {

	// Set up empty array.
	$cats = array();

	// Retrieve available categories.
	$cats_obj = get_categories();

	// Set default/empty tag.
	$cats[''] = __( 'Select a category &hellip;', 'shopy' );

	// Display the tags.
	foreach ( $cats_obj as $cat ) {
		$cats[$cat->term_id] = esc_attr( $cat->name );
	}

	return $cats;

}

/**
 * Display upgrade notice on customizer page
 *
 * @since  1.0.0
 */
function shopy_documentation_link() {

	// Enqueue the script
	wp_enqueue_script(
		'shopy-customizer-doc',
		get_template_directory_uri() . '/admin/js/doc.js',
		array(), '1.0.0',
		true
	);
 
	// Localize the script
	wp_localize_script(
		'shopy-customizer-doc',
		'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/shopy/' ),
			'prefixLabel' => __( 'Documentation', 'shopy' ),
		)
	);
 
}
add_action( 'customize_controls_enqueue_scripts', 'shopy_documentation_link' );