<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function shopy_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //
	
	// Theme prefix
	$prefix = 'shopy-';
	
	// General Panels and Sections
	$general_panel = 'general';

	$panels[] = array(
		'id'       => $general_panel,
		'title'    => __( 'General', 'shopy' ),
		'priority' => 10
	);

		// RSS
		$section = $prefix . 'rss-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'RSS', 'shopy' ),
			'priority'    => 100,
			'panel'       => $general_panel,
			'description' => __( 'If you fill the custom rss url below, it will replace the default.', 'shopy' ),
		);
		$options[$prefix . 'custom-rss'] = array(
			'id'           => $prefix . 'custom-rss',
			'label'        => __( 'Custom RSS URL (eg. Feedburner)', 'shopy' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);

		// Comment
		$section = $prefix . 'comment-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Comments', 'shopy' ),
			'priority'    => 110,
			'panel'       => $general_panel,
		);
		$options[$prefix . 'page-comment'] = array(
			'id'           => $prefix . 'page-comment',
			'label'        => __( 'Page Comment', 'shopy' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Header banner section
		$section = $prefix . 'payment-method-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Payment Method', 'shopy' ),
			'priority'    => 120,
			'panel'       => $general_panel
		);
		$options[$prefix . 'payment-method'] = array(
			'id'           => $prefix . 'payment-method',
			'label'        => '',
			'description'  => __( 'Please upload your shop payment method image.', 'shopy' ),
			'section'      => $section,
			'type'         => 'media',
			'default'      => ''
		);

		// Footer Text
		$section = $prefix . 'footer-text-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer Text', 'shopy' ),
			'priority'    => 120,
			'panel'       => $general_panel,
		);
		$options[$prefix . 'footer-text'] = array(
			'id'           => $prefix . 'footer-text',
			'label'        => '',
			'description'  => __( 'Customize the footer text.', 'shopy' ),
			'section'      => $section,
			'type'         => 'textarea',
			'default'      => '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed by <a href="http://www.theme-junkie.com/">Theme Junkie</a>'
		);

	// Header Panels and Sections
	$header_panel = 'header';

	$panels[] = array(
		'id'       => $header_panel,
		'title'    => __( 'Header', 'shopy' ),
		'priority' => 15
	);

		// Logo
		$section = $prefix . 'logo-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Logo', 'shopy' ),
			'priority'    => 30,
			'panel'       => $header_panel
		);
		$options[$prefix . 'logo'] = array(
			'id'      => $prefix . 'logo',
			'label'   => __( 'Regular Logo', 'shopy' ),
			'section' => $section,
			'type'    => 'image',
			'default' => ''
		);
		$options[$prefix . 'retina-logo'] = array(
			'id'           => $prefix . 'retina-logo',
			'label'        => __( 'Retina Logo', 'shopy' ),
			'description'  => __( 'The Retina Logo should be twice the size of the Regular Logo.', 'shopy' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
		);

		// Search icon
		$section = $prefix . 'search-icon-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Search', 'shopy' ),
			'description' => __( 'Show the search icon', 'shopy' ),
			'priority'    => 35,
			'panel'       => $header_panel
		);
		$options[$prefix . 'search-icon'] = array(
			'id'      => $prefix . 'search-icon',
			'label'   => '',
			'section' => $section,
			'type'    => 'switch',
			'default' => 1
		);

		// Header cart
		$section = $prefix . 'header-cart-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header Cart', 'shopy' ),
			'description' => __( 'Show the header cart', 'shopy' ),
			'priority'    => 40,
			'panel'       => $header_panel
		);
		$options[$prefix . 'header-cart'] = array(
			'id'      => $prefix . 'header-cart',
			'label'   => '',
			'section' => $section,
			'type'    => 'switch',
			'default' => 1
		);

		// Header style
		$section = $prefix . 'header-style-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header Style', 'shopy' ),
			'description' => __( 'There are 4 style for the header, choose the best for you. Click the radio button below and see the changes in real time on your right screen.', 'shopy' ),
			'priority'    => 45,
			'panel'       => $header_panel
		);
		$options[$prefix . 'header-style'] = array(
			'id'      => $prefix . 'header-style',
			'label'   => '',
			'section' => $section,
			'type'    => 'radio',
			'default' => 'one',
			'choices' => array(
				'one'   => __( 'Style One', 'shopy' ),
				'two'   => __( 'Style Two', 'shopy' ),
				'three' => __( 'Style Three', 'shopy' ),
				'four'  => __( 'Style Four', 'shopy' ),
			)
		);

		// Header social
		$section = $prefix . 'header-social-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Social', 'shopy' ),
			'description' => sprintf( __( 'Please add full profile link, for example https://twitter.com/theme_junkie/. The social icons will appear if you choose to use %1$sHeader Style Two%2$s.', 'shopy' ), '<strong>', '</strong>' ),
			'priority'    => 50,
			'panel'       => $header_panel,
		);
		$options[$prefix . 'twitter'] = array(
			'id'           => $prefix . 'twitter',
			'label'        => __( 'Twitter', 'shopy' ),
			'section'      => $section,
			'type'         => 'text'
		);
		$options[$prefix . 'facebook'] = array(
			'id'           => $prefix . 'facebook',
			'label'        => __( 'Facebook', 'shopy' ),
			'section'      => $section,
			'type'         => 'text'
		);
		$options[$prefix . 'gplus'] = array(
			'id'           => $prefix . 'gplus',
			'label'        => __( 'Google Plus', 'shopy' ),
			'section'      => $section,
			'type'         => 'text'
		);
		$options[$prefix . 'instagram'] = array(
			'id'           => $prefix . 'instagram',
			'label'        => __( 'Instagram', 'shopy' ),
			'section'      => $section,
			'type'         => 'text'
		);
		$options[$prefix . 'pinterest'] = array(
			'id'           => $prefix . 'pinterest',
			'label'        => __( 'Pinterest', 'shopy' ),
			'section'      => $section,
			'type'         => 'text'
		);

	// Colors Panel and Sections
	$color_panel = 'color';

	$panels[] = array(
		'id'          => $color_panel,
		'title'       => __( 'Color', 'shopy' ),
		'description' => __( 'This panel is used for managing colors of your site.', 'shopy' ),
		'priority'    => 20
	);
		// Header color
		$section = $prefix . 'header-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header', 'shopy' ),
			'priority'    => 10,
			'panel'       => $color_panel
		);
		$options[$prefix . 'header-bg-color'] = array(
			'id'          => $prefix . 'header-bg-color',
			'label'       => __( 'Background color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ffffff',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'site-title-color'] = array(
			'id'          => $prefix . 'site-title-color',
			'label'       => __( 'Site Title color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#000000',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'site-desc-color'] = array(
			'id'          => $prefix . 'site-desc-color',
			'label'       => __( 'Site Description color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#4a5150',
			'transport'   => 'postMessage'
		);

		// Accent color
		$section = $prefix . 'accent-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Accent', 'shopy' ),
			'priority'    => 20,
			'panel'       => $color_panel
		);
		$options[$prefix . 'primary-color'] = array(
			'id'          => $prefix . 'primary-color',
			'label'       => __( 'Primary color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ffffff',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'text-color'] = array(
			'id'          => $prefix . 'text-color',
			'label'       => __( 'Main Text color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#000000',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'text-alt-1-color'] = array(
			'id'          => $prefix . 'text-alt-1-color',
			'label'       => __( 'Text Alt 1 color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#555555',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'text-alt-2-color'] = array(
			'id'          => $prefix . 'text-alt-2-color',
			'label'       => __( 'Text Alt 2 color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#4a5150',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'text-alt-3-color'] = array(
			'id'          => $prefix . 'text-alt-3-color',
			'label'       => __( 'Text Alt 3 color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#c5727d',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'border-color'] = array(
			'id'          => $prefix . 'border-color',
			'label'       => __( 'Border color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#e9e9e9',
			'transport'   => 'postMessage'
		);

		// Link color
		$section = $prefix . 'link-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Link', 'shopy' ),
			'priority'    => 30,
			'panel'       => $color_panel
		);
		$options[$prefix . 'link-color'] = array(
			'id'          => $prefix . 'link-color',
			'label'       => __( 'Link color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#6187a5',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'hover-color'] = array(
			'id'          => $prefix . 'hover-color',
			'label'       => __( 'Link Hover color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#81a0b8',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'visited-color'] = array(
			'id'          => $prefix . 'visited-color',
			'label'       => __( 'Link Visited color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#567a97',
			'transport'   => 'postMessage'
		);

		// Footer color
		$section = $prefix . 'footer-color-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer', 'shopy' ),
			'priority'    => 40,
			'panel'       => $color_panel
		);
		$options[$prefix . 'footer-bg-color'] = array(
			'id'          => $prefix . 'footer-bg-color',
			'label'       => __( 'Background color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#000000',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'footer-text-color'] = array(
			'id'          => $prefix . 'footer-text-color',
			'label'       => __( 'Text color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ffffff',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'footer-link-color'] = array(
			'id'          => $prefix . 'footer-link-color',
			'label'       => __( 'Link color', 'shopy' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#f2f2f2',
			'transport'   => 'postMessage'
		);

	// Background Image Panels and Sections
	$bgimage_panel = 'bg_image';

	$panels[] = array(
		'id'       => $bgimage_panel,
		'title'    => __( 'Background Image', 'shopy' ),
		'priority' => 25
	);

	// Typography Panel and Sections
	$typo_panel = 'typography';

	$panels[] = array(
		'id'       => $typo_panel,
		'title'    => __( 'Typography', 'shopy' ),
		'priority' => 30
	);

		// Global typography
		$section = $prefix . 'global-typography';
		$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => __( 'Global', 'shopy' ),
			'priority' => 5,
			'panel'    => $typo_panel
		);
		$options[$prefix . 'text-font'] = array(
			'id'          => $prefix . 'text-font',
			'label'       => __( 'Text font', 'shopy' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Nunito',
		);
		$options[$prefix . 'heading-font'] = array(
			'id'          => $prefix . 'heading-font',
			'label'       => __( 'Heading font', 'shopy' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Kameron',
		);

	// Content Panel and Sections
	$content_panel = 'content-layout';

	$panels[] = array(
		'id'          => $content_panel,
		'title'       => __( 'Content Layout', 'shopy' ),
		'description' => __( 'This panel is used for managing several section and layouts content of the theme.', 'shopy' ),
		'priority'    => 35
	);

		// Boxed / Fullwidth
		$section = $prefix . 'boxed-fullwidth-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'General Layout', 'shopy' ),
			'description' => '',
			'priority'    => 5,
			'panel'       => $content_panel,
		);
		$options[$prefix . 'boxed-fullwidth'] = array(
			'id'           => $prefix . 'boxed-fullwidth',
			'label'        => '',
			'description'  => __( 'We provide to general layout, boxed and fullwidth. Please choose the best for you.', 'shopy' ),
			'section'      => $section,
			'type'         => 'radio',
			'default'      => 'boxed',
			'choices'      => array(
				'boxed' => __( 'Boxed', 'shopy' ),
				'full'  => __( 'Full Width', 'shopy' ),
			)
		);

		// Container Width
		$section = $prefix . 'container-width-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Container Width', 'shopy' ),
			'description' => __( 'Set up the maximum width of the layout. (default: 1100)', 'shopy' ),
			'priority'    => 5,
			'panel'       => $content_panel,
		);
		$options[$prefix . 'container-width'] = array(
			'id'           => $prefix . 'container-width',
			'label'        => __( 'Width', 'shopy' ),
			'description'  => __( 'Please be careful with this option. If you set the width larger, it possibly will break your images. Please be wise to set the maximum width. Unit in pixel.', 'shopy' ),
			'section'      => $section,
			'type'         => 'number',
			'default'      => 1100
		);

		// Slider
		$section = $prefix . 'slider-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Slider', 'shopy' ),
			'description' => __( 'You need to use the slider widget we provide to display the slider content. We recommend you to just use it in <strong>Home Sidebar</strong>', 'shopy' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);

		$options[$prefix . 'slider-1-group'] = array(
			'id'          => $prefix . 'slider-1-group',
			'label'       => __( 'Slider 1', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'slider-1'] = array(
				'id'           => $prefix . 'slider-1',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>1060px x 550px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'slider-text-1'] = array(
				'id'           => $prefix . 'slider-text-1',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'slider-url-1'] = array(
				'id'           => $prefix . 'slider-url-1',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		$options[$prefix . 'slider-2-group'] = array(
			'id'          => $prefix . 'slider-2-group',
			'label'       => __( 'Slider 2', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'slider-2'] = array(
				'id'           => $prefix . 'slider-2',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>1060px x 550px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'slider-text-2'] = array(
				'id'           => $prefix . 'slider-text-2',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'slider-url-2'] = array(
				'id'           => $prefix . 'slider-url-2',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		$options[$prefix . 'slider-3-group'] = array(
			'id'          => $prefix . 'slider-3-group',
			'label'       => __( 'Slider 3', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'slider-3'] = array(
				'id'           => $prefix . 'slider-3',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>1060px x 550px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'slider-text-3'] = array(
				'id'           => $prefix . 'slider-text-3',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'slider-url-3'] = array(
				'id'           => $prefix . 'slider-url-3',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		$options[$prefix . 'slider-4-group'] = array(
			'id'          => $prefix . 'slider-4-group',
			'label'       => __( 'Slider 4', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'slider-4'] = array(
				'id'           => $prefix . 'slider-4',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>1060px x 550px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'slider-text-4'] = array(
				'id'           => $prefix . 'slider-text-4',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'slider-url-4'] = array(
				'id'           => $prefix . 'slider-url-4',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		$options[$prefix . 'slider-5-group'] = array(
			'id'          => $prefix . 'slider-5-group',
			'label'       => __( 'Slider 5', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'slider-5'] = array(
				'id'           => $prefix . 'slider-5',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>1060px x 550px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'slider-text-5'] = array(
				'id'           => $prefix . 'slider-text-5',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'slider-url-5'] = array(
				'id'           => $prefix . 'slider-url-5',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		// Posts
		$section = $prefix . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'shopy' ),
			'description' => __( 'Posts is a blog and single post page.', 'shopy' ),
			'priority'    => 10,
			'panel'       => $content_panel
		);
		$options[$prefix . 'post-meta-group'] = array(
			'id'          => $prefix . 'post-meta-group',
			'label'       => __( 'Post Meta', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-author'] = array(
				'id'          => $prefix . 'post-author',
				'label'       => __( 'Show post author name', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-date'] = array(
				'id'          => $prefix . 'post-date',
				'label'       => __( 'Show post date', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-comment-link'] = array(
				'id'          => $prefix . 'post-comment-link',
				'label'       => __( 'Show post comment link', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-author-box'] = array(
				'id'          => $prefix . 'post-author-box',
				'label'       => __( 'Show post author box', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[$prefix . 'post-date-group'] = array(
			'id'          => $prefix . 'post-date-group',
			'label'       => __( 'Post Date', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-date-style'] = array(
				'id'          => $prefix . 'post-date-style',
				'label'       => __( 'Style', 'shopy' ),
				'section'     => $section,
				'type'        => 'select',
				'default'     => 'absolute',
				'choices'     => array(
					'absolute' => __( 'Absolute (June 20, 2015 10:19 am)', 'shopy' ),
					'relative' => __( 'Relative (1 week ago)', 'shopy' )
				)
			);
		$options[$prefix . 'post-footer-group'] = array(
			'id'          => $prefix . 'post-footer-group',
			'label'       => __( 'Category and Tag', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-cat'] = array(
				'id'          => $prefix . 'post-cat',
				'label'       => __( 'Show post categories', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-tag'] = array(
				'id'          => $prefix . 'post-tag',
				'label'       => __( 'Show post tags', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[$prefix . 'related-posts-group'] = array(
			'id'          => $prefix . 'related-posts-group',
			'label'       => __( 'Related Posts', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'related-posts'] = array(
				'id'          => $prefix . 'related-posts',
				'label'       => __( 'Show related posts', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'related-posts-img'] = array(
				'id'          => $prefix . 'related-posts-img',
				'label'       => __( 'Show related posts thumbnail', 'shopy' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);

		// Page
		$section = $prefix . 'page-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Page', 'shopy' ),
			'priority'    => 15,
			'panel'       => $content_panel
		);
		$options[$prefix . 'page-title'] = array(
			'id'          => $prefix . 'page-title',
			'label'       => __( 'Show page title', 'shopy' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Header banner section
		$section = $prefix . 'banner-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Banner', 'shopy' ),
			'description' => __( 'Banner will appear automatically on shop and product category/tag page. But you can also display it on home page using special widget we provide.', 'shopy' ),
			'priority'    => 20,
			'panel'       => $content_panel
		);

		$options[$prefix . 'banner-1-group'] = array(
			'id'          => $prefix . 'banner-1-group',
			'label'       => __( 'Banner 1', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'banner-1'] = array(
				'id'           => $prefix . 'banner-1',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>340px x 200px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'banner-text-1'] = array(
				'id'           => $prefix . 'banner-text-1',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'banner-url-1'] = array(
				'id'           => $prefix . 'banner-url-1',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		$options[$prefix . 'banner-2-group'] = array(
			'id'          => $prefix . 'banner-2-group',
			'label'       => __( 'Header Banner 2', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'banner-2'] = array(
				'id'           => $prefix . 'banner-2',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>340px x 200px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'banner-text-2'] = array(
				'id'           => $prefix . 'banner-text-2',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'banner-url-2'] = array(
				'id'           => $prefix . 'banner-url-2',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		$options[$prefix . 'banner-3-group'] = array(
			'id'          => $prefix . 'banner-3-group',
			'label'       => __( 'Header Banner 3', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'banner-3'] = array(
				'id'           => $prefix . 'banner-3',
				'label'        => '',
				'description'  => __( 'File must be <strong>.png</strong> or <strong>.jpg</strong> format. Optimal dimensions: <strong>340px x 200px</strong>.', 'shopy' ),
				'section'      => $section,
				'type'         => 'media',
				'default'      => ''
			);
			$options[$prefix . 'banner-text-3'] = array(
				'id'           => $prefix . 'banner-text-3',
				'label'        => __( 'Text', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'banner-url-3'] = array(
				'id'           => $prefix . 'banner-url-3',
				'label'        => __( 'Url', 'shopy' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);

		// Spotlight section
		$section = $prefix . 'spotlight-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Spotlight', 'shopy' ),
			'description' => __( 'Spotlight is a 3 columns information at the bottom of the page.', 'shopy' ),
			'priority'    => 25,
			'panel'       => $content_panel
		);

		$options[$prefix . 'spotlight-1-group'] = array(
			'id'          => $prefix . 'spotlight-1-group',
			'label'       => __( 'Spotlight 1', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'spotlight-1'] = array(
				'id'           => $prefix . 'spotlight-1',
				'label'        => __( 'Title', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'spotlight-1-desc'] = array(
				'id'           => $prefix . 'spotlight-1-desc',
				'label'        => __( 'Description', 'shopy' ),
				'section'      => $section,
				'type'         => 'textarea',
				'default'      => ''
			);
			$options[$prefix . 'spotlight-1-icon'] = array(
				'id'                => $prefix . 'spotlight-1-icon',
				'label'             => __( 'Icon', 'shopy' ),
				'description'       => sprintf( __( 'Please go to %1$sFontAwesome page%2$s to pick your icon, click the icon then copy paste the HTML tag you get. (eg. <code>&lt;i class=&quot;fa fa-heart&quot;&gt;&lt;/i&gt;</code>)', 'shopy' ), '<a href="http://fontawesome.io/icons/" target="_blank">', '</a>' ),
				'section'           => $section,
				'type'              => 'text',
				'default'           => '<i class="fa fa-heart"></i>',
				'sanitize_callback' => 'shopy_sanitize_fontawesome_tag'
			);

		$options[$prefix . 'spotlight-2-group'] = array(
			'id'          => $prefix . 'spotlight-2-group',
			'label'       => __( 'Spotlight 2', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'spotlight-2'] = array(
				'id'           => $prefix . 'spotlight-2',
				'label'        => __( 'Title', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'spotlight-2-desc'] = array(
				'id'           => $prefix . 'spotlight-2-desc',
				'label'        => __( 'Description', 'shopy' ),
				'section'      => $section,
				'type'         => 'textarea',
				'default'      => ''
			);
			$options[$prefix . 'spotlight-2-icon'] = array(
				'id'                => $prefix . 'spotlight-2-icon',
				'label'             => __( 'Icon', 'shopy' ),
				'description'       => sprintf( __( 'Please go to %1$sFontAwesome page%2$s to pick your icon, click the icon then copy paste the HTML tag you get. (eg. <code>&lt;i class=&quot;fa fa-heart&quot;&gt;&lt;/i&gt;</code>)', 'shopy' ), '<a href="http://fontawesome.io/icons/" target="_blank">', '</a>' ),
				'section'           => $section,
				'type'              => 'text',
				'default'           => '<i class="fa fa-heart"></i>',
				'sanitize_callback' => 'shopy_sanitize_fontawesome_tag'
			);

		$options[$prefix . 'spotlight-3-group'] = array(
			'id'          => $prefix . 'spotlight-3-group',
			'label'       => __( 'Spotlight 3', 'shopy' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'spotlight-3'] = array(
				'id'           => $prefix . 'spotlight-3',
				'label'        => __( 'Title', 'shopy' ),
				'section'      => $section,
				'type'         => 'text',
				'default'      => ''
			);
			$options[$prefix . 'spotlight-3-desc'] = array(
				'id'           => $prefix . 'spotlight-3-desc',
				'label'        => __( 'Description', 'shopy' ),
				'section'      => $section,
				'type'         => 'textarea',
				'default'      => ''
			);
			$options[$prefix . 'spotlight-3-icon'] = array(
				'id'                => $prefix . 'spotlight-3-icon',
				'label'             => __( 'Icon', 'shopy' ),
				'description'       => sprintf( __( 'Please go to %1$sFontAwesome page%2$s to pick your icon, click the icon then copy paste the HTML tag you get. (eg. <code>&lt;i class=&quot;fa fa-heart&quot;&gt;&lt;/i&gt;</code>)', 'shopy' ), '<a href="http://fontawesome.io/icons/" target="_blank">', '</a>' ),
				'section'           => $section,
				'type'              => 'text',
				'default'           => '<i class="fa fa-heart"></i>',
				'sanitize_callback' => 'shopy_sanitize_fontawesome_tag'
			);

	// Footer Panel and Sections
	$footer_panel = 'footer-section';

	$panels[] = array(
		'id'          => $footer_panel,
		'title'       => __( 'Footer', 'shopy' ),
		'description' => __( 'This panel is used for managing footer are of the theme.', 'shopy' ),
		'priority'    => 40
	);

		// Footer style
		$section = $prefix . 'footer-style-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer Style', 'shopy' ),
			'description' => __( 'There are 2 style for the footer, choose the best for you. Click the radio button below and see the changes in real time on your right screen.', 'shopy' ),
			'priority'    => 5,
			'panel'       => $footer_panel
		);
		$options[$prefix . 'footer-style'] = array(
			'id'      => $prefix . 'footer-style',
			'label'   => '',
			'section' => $section,
			'type'    => 'radio',
			'default' => 'one',
			'choices' => array(
				'one'   => __( 'Style One', 'shopy' ),
				'two'   => __( 'Style Two', 'shopy' )
			)
		);


	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'shopy_customizer_register' );