<?php
/**
 * Header color
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'shopy_customizer_link_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0
 */
function shopy_customizer_link_styles() {

	// Theme prefix
	$prefix = 'shopy-';
	
	// Link color
	$link = shopy_mod( $prefix . 'link-color' );

	if ( $link !== customizer_library_get_default( $prefix . 'link-color' ) ) {

		$color = sanitize_hex_color( $link );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'a',
				'.top-navigation .sub-menu li.current-menu-item a',
				'.top-navigation .sub-menu a:hover',
				'.primary-navigation li.current-menu-item > a',
				'.primary-navigation li.menu-item-has-children::after:hover',
				'.primary-navigation li.menu-item-has-children:hover > a',
				'.primary-navigation a:hover',
				'.primary-navigation .sub-menu li.current-menu-item a',
				'.primary-navigation .sub-menu a:hover',
				'.entry-header .entry-title a:hover',
				'.author-bio .author-title a:hover',
				'.author-bio .author-social a:hover',
				'.related-posts .entry-title a:hover',
				'.loop-nav a:hover',
				'.widget li a:hover',
				'.widget_rss li a',
				'ul.products li.product .price',
				'ul.products li.product .button:hover',
				'.single-product div.product .in-stock',
				'.woocommerce-breadcrumb a:hover',
				'.star-rating span:before',
				'p.stars a',
				'p.stars a:hover',
				'.gridlist-toggle a.active,.gridlist-toggle a:hover',
				'.product_list_widget a:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'::selection',
				// '::-moz-selection',
				'button,input[type="button"],input[type="reset"],input[type="submit"],.button',
				'.more-link:hover',
				'.tag-links a:hover',
				'.widget_tag_cloud a:hover',
				'.subscribe-widget button:hover',
				'.widget_social a:hover',
				'#scrollUp:hover',
				'.author-badge',
				'form.comment-form input[type="submit"]',
				'.header-cart .count',
				'.banner .banner-item:hover > .overlay',
				'.onsale',
				'.widget_shopping_cart .buttons .button.checkout',
				'.widget_product_tag_cloud a:hover',
				'.widget_price_filter .price_slider_amount .button'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.primary-navigation li.current-menu-item > a',
				'.primary-navigation a:hover'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

	// Link Hover color
	$hover = shopy_mod( $prefix . 'hover-color' );

	if ( $hover !== customizer_library_get_default( $prefix . 'hover-color' ) ) {

		$color = sanitize_hex_color( $hover );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'a:hover,a:visited:hover'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Link Visited color
	$visited = shopy_mod( $prefix . 'visited-color' );

	if ( $visited !== customizer_library_get_default( $prefix . 'visited-color' ) ) {

		$color = sanitize_hex_color( $visited );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'a:visited'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'button,input[type="button"],input[type="reset"],input[type="submit"],.button'
			),
			'declarations' => array(
				'border-color' => $color
			)
		) );
	}

}
endif;
add_action( 'shopy_customizer_library_styles', 'shopy_customizer_link_styles' );