<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'shopy_site_branding' ) ) :
/**
 * Site branding for the site.
 *
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 *
 * @since  1.0.0
 */
function shopy_site_branding() {

	// Get the customizer value.
	$prefix = 'shopy-';
	$logo   = shopy_mod( $prefix . 'logo' );

	// Check if logo available, then display it.
	if ( $logo ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<div id="logo">'. "\n";
			echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
			echo '<h2 class="site-description" ' . hybrid_get_attr( 'site-description' ) . '>' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
		echo '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'shopy_social_links' ) ) :
/**
 * Social profile links
 *
 * @since  1.0.0
 */
function shopy_social_links() {

	// Theme prefix
	$prefix = 'shopy-';

	// Get the data set in customizer
	$twitter   = shopy_mod( $prefix . 'twitter' );
	$facebook  = shopy_mod( $prefix . 'facebook' );
	$gplus     = shopy_mod( $prefix . 'gplus' );
	$instagram = shopy_mod( $prefix . 'instagram' );
	$pinterest = shopy_mod( $prefix . 'pinterest' );
	$header    = shopy_mod( $prefix . 'header-style' );

	// Dont display the social icons if header two not used.
	if ( $header != 'two' ) {
		return;
	}

	// Display the data
	echo '<div class="social-links">';
		if ( $twitter ) {
			echo '<a href="' . esc_url( $twitter ) . '"><i class="fa fa-twitter"></i></a>';
		}
		if ( $facebook ) {
			echo '<a href="' . esc_url( $facebook ) . '"><i class="fa fa-facebook"></i></a>';
		}
		if ( $gplus ) {
			echo '<a href="' . esc_url( $gplus ) . '"><i class="fa fa-google-plus"></i></a>';
		}
		if ( $instagram ) {
			echo '<a href="' . esc_url( $instagram ) . '"><i class="fa fa-instagram"></i></a>';
		}
		if ( $pinterest ) {
			echo '<a href="' . esc_url( $pinterest ) . '"><i class="fa fa-pinterest"></i></a>';
		}
	echo '</div>';

}
endif;

if ( ! function_exists( 'shopy_banner' ) ) :
/**
 * Display banner
 *
 * @since  1.0.0
 */
function shopy_banner() {

	// Prefix
	$prefix = 'shopy-';

	// Get the data from Customizer
	// Banner 1
	$banner_1      = shopy_mod( $prefix . 'banner-1' );
	$banner_1_text = shopy_mod( $prefix . 'banner-text-1' );
	$banner_1_url  = shopy_mod( $prefix . 'banner-url-1' );

	// Banner 2
	$banner_2      = shopy_mod( $prefix . 'banner-2' );
	$banner_2_text = shopy_mod( $prefix . 'banner-text-2' );
	$banner_2_url  = shopy_mod( $prefix . 'banner-url-2' );

	// Banner 3
	$banner_3      = shopy_mod( $prefix . 'banner-3' );
	$banner_3_text = shopy_mod( $prefix . 'banner-text-3' );
	$banner_3_url  = shopy_mod( $prefix . 'banner-url-3' );

	// Polylang integration
	if ( is_polylang_activated() ) {
		$banner_1_text = pll__( shopy_mod( $prefix . 'banner-text-1' ) );
		$banner_2_text = pll__( shopy_mod( $prefix . 'banner-text-2' ) );
		$banner_3_text = pll__( shopy_mod( $prefix . 'banner-text-3' ) );
	}

	if ( $banner_1 || $banner_2 || $banner_3 ) :
		echo '<div class="banner">';

			if ( $banner_1 ) {
				echo '<a class="banner-item" href="' . esc_url( $banner_1_url ) . '">';
					echo wp_get_attachment_image( absint( $banner_1 ), 'shopy-banner' );
					echo '<span class="overlay"><span class="text-wrapper"><span class="banner-text">' . esc_attr( $banner_1_text ) . '</span></span></span>';
				echo '</a>';
			}

			if ( $banner_2 ) {
				echo '<a class="banner-item" href="' . esc_url( $banner_2_url ) . '">';
					echo wp_get_attachment_image( absint( $banner_2 ), 'shopy-banner' );
					echo '<span class="overlay"><span class="text-wrapper"><span class="banner-text">' . esc_attr( $banner_2_text ) . '</span></span></span>';
				echo '</a>';
			}

			if ( $banner_3 ) {
				echo '<a class="banner-item" href="' . esc_url( $banner_3_url ) . '">';
					echo wp_get_attachment_image( absint( $banner_3 ), 'shopy-banner' );
					echo '<span class="overlay"><span class="text-wrapper"><span class="banner-text">' . esc_attr( $banner_3_text ) . '</span></span></span>';
				echo '</a>';
			}

		echo '</div>';
	endif;

}
endif;

if ( ! function_exists( 'shopy_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function shopy_posted_on() {

	// Theme prefix
	$prefix = 'shopy-';

	// Get the data set in customizer
	$author     = shopy_mod( $prefix . 'post-author' );
	$cat        = shopy_mod( $prefix . 'post-cat' );
	$comment    = shopy_mod( $prefix . 'post-comment-link' );
	$date       = shopy_mod( $prefix . 'post-date' );
	$date_style = shopy_mod( $prefix . 'post-date-style' );

	// Set up empty variable
	$style = '';
	if ( $date_style == 'absolute' ) {
		$style = esc_html( get_the_date() );
	} else {
		$style = sprintf( __( '%s ago', 'shopy' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
	}
	?>
	<?php if ( $date ) : ?>
		<time class="entry-date published" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( $style ); ?></time>
	<?php endif; ?>

	<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) && $comment ) : ?>
		<span class="comments-link"><?php comments_popup_link( __( 'Leave a Comment', 'shopy' ), __( '1 Comment', 'shopy' ), __( '% Comments', 'shopy' ) ); ?></span>
	<?php endif; ?>

	<?php if ( $author ) : ?>
		<span class="byline"><?php printf( __( 'by %s', 'shopy' ), '<span class="author vcard" ' . hybrid_get_attr( 'entry-author' ) . '><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></a></span>' ); ?></span>
	<?php endif; ?>

	<?php if ( 'post' == get_post_type() ) : ?>
		<?php
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( __( ', ', 'shopy' ) );
			if ( $categories_list && shopy_categorized_blog() && $cat ) :
		?>
		<span class="cat-links" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
			<?php printf( __( 'in %s', 'shopy' ), $categories_list ) ?>
		</span>
		<?php endif; // End if categories ?>
	<?php endif; ?>

	<?php
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function shopy_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'shopy_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'shopy_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so shopy_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so shopy_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in shopy_categorized_blog.
 *
 * @since 1.0.0
 */
function shopy_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'shopy_categories' );
}
add_action( 'edit_category', 'shopy_category_transient_flusher' );
add_action( 'save_post',     'shopy_category_transient_flusher' );

if ( ! function_exists( 'shopy_get_post_format_link_url' ) ) :
/**
 * Forked from hybrid_get_the_post_format_url.
 * Filters 'get_the_post_format_url' to make for a more robust and back-compatible function.  If WP did
 * not find a URL, check the post content for one.  If nothing is found, return the post permalink.
 * Used in Post Format Link
 *
 * @since 1.0.0
 */
function shopy_get_post_format_link_url( $url = '', $post = null ) {

	if ( empty( $url ) ) {

		$post = is_null( $post ) ? get_post() : $post;

		/* Catch links that are not wrapped in an '<a>' tag. */
		$content_url = preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', make_clickable( $post->post_content ), $matches );

		$content_url = ! empty( $matches[1] ) ? esc_url_raw( $matches[1] ) : '';

		$url = ! empty( $content_url ) ? $content_url : get_permalink( $post->ID );
	}

	if ( $url ) {
	?>
		<h2 class="entry-title" itemprop="headline">
			<a href="<?php echo esc_url( $url ); ?>" itemprop="url">
				<?php if ( get_the_title() && ( __( '(Untitled)', 'shopy' ) != get_the_title() ) ) { ?>
					<?php the_title(); ?>
				<?php } else { ?>
					<?php echo esc_attr( $url ); ?>
				<?php }	?>
			</a>
		</h2>
	<?php
	}

}
endif;

if ( ! function_exists( 'shopy_get_format_gallery' ) ) :
/**
 * Get the [gallery] shortcode from the post content and display it on index page. It require
 * gallery ids [gallery ids=1,2,3,4] to display it as thumbnail slideshow. If no ids exist it
 * just display it as standard [gallery] markup.
 *
 * If no [gallery] shortcode found in the post content, get the attached images to the post and
 * display it as slideshow.
 *
 * @since  1.0.0
 * @uses   get_post_gallery() to get the gallery in the post content.
 * @uses   wp_get_attachment_image() to get the HTML image.
 * @uses   get_children() to get the attached images if no [gallery] found in the post content.
 * @return string
 */
function shopy_get_format_gallery() {
	global $post;

	// Set up a default, empty $html variable.
	$html = '';

	// Set up default image size.
	$size = 'large';

	// Check the [gallery] shortcode in post content.
	$gallery = get_post_gallery( $post->ID, false );

	// opening wrapper
	$html = '<div class="owl-carousel owl-theme entry-format">';

		// Check if the [gallery] exist.
		if ( $gallery ) {

			// Check if the gallery ids exist.
			if ( isset( $gallery['ids'] ) ) {

				// Get the gallery ids and convert it into array.
				$ids = explode( ',', $gallery['ids'] );

				// Display the gallery in a cool slideshow on index page.
				foreach( $ids as $id ) {
					$html .= '<div class="item">';
					$html .= wp_get_attachment_image( $id, $size, false, array( 'class' => 'entry-thumbnail' ) );
					$html .= '</div>';
				}

			} else {

				// If gallery ids not exist, display the standard gallery markup.
				// avoid this, since it'll look bad
				// $html = get_post_gallery( $post->ID );

				// if gallery based on images attached to post (only [gallery] in post content)
				// note: in the post content, better to use: [gallery size="large"] or [gallery size="full"]
				$srcs = $gallery['src'];

				// Display the gallery in a cool slideshow on index page.
				foreach( $srcs as $src ) {
					$html .= '<div class="item">';
					$html .= '<img src="' . esc_url( $src ) . '" />';
					$html .= '</div>';
				}

			}

		// If no [gallery] in post content, get attached images to the post.
		} else {

			// Set up default arguments.
			$defaults = array(
				'order'          => 'ASC',
				'post_type'      => 'attachment',
				'post_parent'    => $post->ID,
				'post_mime_type' => 'image',
				'numberposts'    => -1
			);

			// Retrieves attachments from the post.
			$attachments = get_children( apply_filters( 'shopy_gallery_format_args', $defaults ) );

			// Check if attachments exist.
			if ( $attachments ) {

				// Display the attachment images in a cool slideshow on index page.
				foreach ( $attachments as $attachment ) {
					$html .= '<div class="item">';
					$html .= wp_get_attachment_image( $attachment->ID, $size, false, array( 'class' => 'entry-thumbnail' ) );
					$html .= '</div>';
				}

			} else {

				// if no [gallery] shortcode and has no attachments, bail them out
				return;

			}

		}

	// closing wrapper
	$html .= '</div>';

	// Return the gallery images.
	return $html;

}
endif;

if ( ! function_exists( 'shopy_post_author' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function shopy_post_author() {

	// Theme prefix
	$prefix = 'shopy-';

	// Get the data set in customizer
	$enable = shopy_mod( $prefix . 'post-author-box' );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Bail if not on the single post.
	if ( ! is_single() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}
?>

	<div class="author-bio clearfix" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'shopy_author_bio_avatar_size', 64 ), '', strip_tags( get_the_author() ) ); ?>
		<div class="description">
			<h3 class="author-title name">
				<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
			</h3>
			<p class="bio" itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>
			<ul class="author-social">
				<?php if ( get_the_author_meta( 'url' ) ) : ?>
					<li class="website">
						<a href="<?php echo esc_url( get_the_author_meta( 'url' ) ); ?>"><i class="fa fa-home"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'twitter' ) ) : ?>
					<li class="twitter">
						<a href="<?php echo esc_url( get_the_author_meta( 'twitter' ) ); ?>"><i class="fa fa-twitter"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'facebook' ) ) : ?>
					<li class="facebook">
						<a href="<?php echo esc_url( get_the_author_meta( 'facebook' ) ); ?>"><i class="fa fa-facebook"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'gplus' ) ) : ?>
					<li class="gplus">
						<a href="<?php echo esc_url( get_the_author_meta( 'gplus' ) ); ?>"><i class="fa fa-google-plus"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'instagram' ) ) : ?>
					<li class="instagram">
						<a href="<?php echo esc_url( get_the_author_meta( 'instagram' ) ); ?>"><i class="fa fa-instagram"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'linkedin' ) ) : ?>
					<li class="linkedin">
						<a href="<?php echo esc_url( get_the_author_meta( 'linkedin' ) ); ?>"><i class="fa fa-linkedin"></i></a>
					</li>
				<?php endif; ?>
			</ul>
		</div>
	</div><!-- .author-bio -->

<?php
}
endif;

if ( ! function_exists( 'shopy_related_posts' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function shopy_related_posts() {
	global $post;

	// Theme prefix
	$prefix = 'shopy-';

	// Get the data set in customizer
	$enable  = shopy_mod( $prefix . 'related-posts' );
	$img     = shopy_mod( $prefix . 'related-posts-img' );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( $post->ID, 'category', array( 'fields' => 'ids' ) );

	// Bail if the term empty.
	if ( empty( $terms ) ) {
		return;
	}

	// Posts query arguments.
	$query = array(
		'post__not_in' => array( $post->ID ),
		'tax_query'    => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => 3,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'shopy_related_posts_args', $query );

	// The post query
	$related = new WP_Query( $args );

	if ( $related->have_posts() ) : ?>

		<div class="related-posts">
			<h3><?php _e( 'You might also like:', 'shopy' ); ?></h3>
			<ul class="clearfix">
				<?php while ( $related->have_posts() ) : $related->the_post(); ?>
					<li>
						<?php if ( has_post_thumbnail() && $img ) : ?>
							<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'medium', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
						<?php endif; ?>
						<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
						<time class="published" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() ); ?></time>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'shopy_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function shopy_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">
			<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'shopy' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'shopy' ), '<span class="edit-link">', '</span>' ); ?></p>
		</article>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">

			<div class="comment-avatar">
				<?php echo get_avatar( $comment, apply_filters( 'shopy_comment_avatar_size', 80 ) ); ?>
				<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
				<?php echo shopy_comment_author_badge(); ?>
			</div>

			<div class="comment-body">
				<div class="comment-wrapper">

					<div class="comment-head">
						<?php
							printf( '<span class="date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</span>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'shopy' ), get_comment_date(), get_comment_time() ),
								sprintf( __( '%1$s&middot; Edit%2$s', 'shopy' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'shopy' ) . '">', '</a>' )
							);
						?>
					</div><!-- comment-head -->

					<div class="comment-content comment-entry" <?php hybrid_attr( 'comment-content' ); ?>>
						<?php if ( '0' == $comment->comment_approved ) : ?>
							<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'shopy' ); ?></p>
						<?php endif; ?>
						<?php comment_text(); ?>
						<span class="reply">
							<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( '<i class="fa fa-reply"></i> Reply', 'shopy' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
						</span><!-- .reply -->
					</div><!-- .comment-content -->

				</div>
			</div>

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'shopy_comment_author_badge' ) ) :
/**
 * Custom badge for post author comment
 *
 * @since  1.0.0
 */
function shopy_comment_author_badge() {

	// Set up empty variable
	$output = '';

	// Get comment classes
	$classes = get_comment_class();

	if ( in_array( 'bypostauthor', $classes ) ) {
		$output = '<span class="author-badge">' . __( 'Author', 'shopy' ) . '</span>';
	}

	// Display the badge
	return apply_filters( 'shopy_comment_author_badge', $output );
}
endif;

if ( ! function_exists( 'shopy_spotlight' ) ) :
/**
 * 3 columns information at the bottom of the page.
 *
 * @since  1.0.0
 */
function shopy_spotlight() {

	// Prefix
	$prefix = 'shopy-';

	// Get the data from Customizer
	// Spotlight 1
	$spotlight_1      = shopy_mod( $prefix . 'spotlight-1' );
	$spotlight_1_desc = shopy_mod( $prefix . 'spotlight-1-desc' );
	$spotlight_1_icon = shopy_mod( $prefix . 'spotlight-1-icon' );

	// Spotlight 2
	$spotlight_2      = shopy_mod( $prefix . 'spotlight-2' );
	$spotlight_2_desc = shopy_mod( $prefix . 'spotlight-2-desc' );
	$spotlight_2_icon = shopy_mod( $prefix . 'spotlight-2-icon' );

	// Spotlight 3
	$spotlight_3      = shopy_mod( $prefix . 'spotlight-3' );
	$spotlight_3_desc = shopy_mod( $prefix . 'spotlight-3-desc' );
	$spotlight_3_icon = shopy_mod( $prefix . 'spotlight-3-icon' );

	// Polylang integration
	if ( is_polylang_activated() ) {
		$spotlight_1      = pll__( shopy_mod( $prefix . 'spotlight-1' ) );
		$spotlight_1_desc = pll__( shopy_mod( $prefix . 'spotlight-1-desc' ) );
		$spotlight_2      = pll__( shopy_mod( $prefix . 'spotlight-2' ) );
		$spotlight_2_desc = pll__( shopy_mod( $prefix . 'spotlight-2-desc' ) );
		$spotlight_3      = pll__( shopy_mod( $prefix . 'spotlight-3' ) );
		$spotlight_3_desc = pll__( shopy_mod( $prefix . 'spotlight-3-desc' ) );
	}

	if ( $spotlight_1 || $spotlight_2 || $spotlight_3 ) :
		echo '<div class="spotlight">';
			echo '<div class="container">';
				echo '<div class="spotlight-items">';

					if ( $spotlight_1 ) {
						echo '<div class="spotlight-item">';
							echo $spotlight_1_icon;
							echo '<h3>' . esc_attr( $spotlight_1 ) . '</h3>';
							echo '<p>' . esc_textarea( $spotlight_1_desc ) . '</p>';
						echo '</div>';
					}

					if ( $spotlight_2 ) {
						echo '<div class="spotlight-item">';
							echo $spotlight_2_icon;
							echo '<h3>' . esc_attr( $spotlight_2 ) . '</h3>';
							echo '<p>' . esc_textarea( $spotlight_2_desc ) . '</p>';
						echo '</div>';
					}

					if ( $spotlight_3 ) {
						echo '<div class="spotlight-item">';
							echo $spotlight_3_icon;
							echo '<h3>' . esc_attr( $spotlight_3 ) . '</h3>';
							echo '<p>' . esc_textarea( $spotlight_3_desc ) . '</p>';
						echo '</div>';
					}

				echo '</div>';
			echo '</div>';
		echo '</div>';
	endif;

}
endif;

if ( ! function_exists( 'shopy_footer_text' ) ) :
/**
 * Footer Text
 */
function shopy_footer_text() {

	// Theme prefix
	$prefix = 'shopy-';

	// Get the customizer data
	$footer_text = shopy_mod( $prefix . 'footer-text' );

	if ( is_polylang_activated() ) {
		$text = pll__( $footer_text );
	} else {
		$text = $footer_text;
	}

	// Display the data
	echo '<p class="copyright">' . stripslashes( $text ) . '</p>';

}
endif;

if ( ! function_exists( 'shopy_blog_query' ) ) :
/**
 * Blog query
 */
function shopy_blog_query() {

	// Pagination
	$paged = ( get_query_var('paged') ) ? get_query_var('paged') : 1;

	// Arguments
	$args = array(
		'post_type' => 'post',
		'paged'     => $paged
	);

	// Query
	$query = new WP_Query( $args );

	return $query;

}
endif;
