<?php
/**
 * Products widget.
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Shopy_Products_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-shopy-products',
			'description' => __( 'Display products. To be use in Front Page sidebar.', 'shopy' )
		);

		// Create the widget.
		parent::__construct(
			'shopy-products',                 // $this->id_base
			__( 'Home - Products', 'shopy' ), // $this->name
			$widget_options                   // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
		}

			if ( $instance['product'] == 'recent' ) {
				echo do_shortcode( '[recent_products per_page="4" columns="4"]' );
			} elseif ( $instance['product'] == 'featured' ) {
				echo do_shortcode( '[featured_products per_page="4" columns="4"]' );
			} elseif ( $instance['product'] == 'sale' ) {
				echo do_shortcode( '[sale_products per_page="4" columns="4"]' );
			} elseif ( $instance['product'] == 'bestselling' ) {
				echo do_shortcode( '[best_selling_products per_page="4" columns="4"]' );
			} else {
				echo do_shortcode( '[top_rated_products per_page="4" columns="4"]' );
			}

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title']   = strip_tags( $new_instance['title'] );
		$instance['product'] = strip_tags( $new_instance['product'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'   => esc_html__( 'Recent Products', 'shopy' ),
			'product' => 'recent'
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php _e( 'Title', 'shopy' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'product' ); ?>">
				<?php _e( 'Display', 'shopy' ); ?>
			</label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'product' ); ?>" name="<?php echo $this->get_field_name( 'product' ); ?>" style="width:100%;">
				<option value="recent" <?php selected( $instance['product'], 'recent' ); ?>><?php _e( 'Recent Products', 'shopy' ) ?></option>
				<option value="featured" <?php selected( $instance['product'], 'featured' ); ?>><?php _e( 'Featured Products', 'shopy' ) ?></option>
				<option value="sale" <?php selected( $instance['product'], 'sale' ); ?>><?php _e( 'Sale Products', 'shopy' ) ?></option>
				<option value="bestselling" <?php selected( $instance['product'], 'bestselling' ); ?>><?php _e( 'Best-Selling Products', 'shopy' ) ?></option>
				<option value="toprated" <?php selected( $instance['product'], 'toprated' ); ?>><?php _e( 'Top Rated Products', 'shopy' ) ?></option>
			</select>
		</p>

	<?php

	}

}