<?php
/**
 * Slider widget.
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Shopy_Slider_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-shopy-slider',
			'description' => __( 'Display slider set in Customizer. To be use in Front Page sidebar.', 'shopy' )
		);

		// Create the widget.
		parent::__construct(
			'shopy-slider',                 // $this->id_base
			__( 'Home - Slider', 'shopy' ), // $this->name
			$widget_options                 // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Prefix
			$prefix = 'shopy-';

			// Get the data from Customizer
			// Slider 1
			$slider_1      = shopy_mod( $prefix . 'slider-1' );
			$slider_1_text = shopy_mod( $prefix . 'slider-text-1' );
			$slider_1_url  = shopy_mod( $prefix . 'slider-url-1' );

			// Slider 2
			$slider_2      = shopy_mod( $prefix . 'slider-2' );
			$slider_2_text = shopy_mod( $prefix . 'slider-text-2' );
			$slider_2_url  = shopy_mod( $prefix . 'slider-url-2' );

			// Slider 3
			$slider_3      = shopy_mod( $prefix . 'slider-3' );
			$slider_3_text = shopy_mod( $prefix . 'slider-text-3' );
			$slider_3_url  = shopy_mod( $prefix . 'slider-url-3' );

			// Slider 4
			$slider_4      = shopy_mod( $prefix . 'slider-4' );
			$slider_4_text = shopy_mod( $prefix . 'slider-text-4' );
			$slider_4_url  = shopy_mod( $prefix . 'slider-url-4' );

			// Slider 5
			$slider_5      = shopy_mod( $prefix . 'slider-5' );
			$slider_5_text = shopy_mod( $prefix . 'slider-text-5' );
			$slider_5_url  = shopy_mod( $prefix . 'slider-url-5' );

			// Polylang integration
			if ( is_polylang_activated() ) {
				$slider_1_text = pll__( shopy_mod( $prefix . 'slider-text-1' ) );
				$slider_2_text = pll__( shopy_mod( $prefix . 'slider-text-2' ) );
				$slider_3_text = pll__( shopy_mod( $prefix . 'slider-text-3' ) );
				$slider_4_text = pll__( shopy_mod( $prefix . 'slider-text-4' ) );
				$slider_5_text = pll__( shopy_mod( $prefix . 'slider-text-5' ) );
			}

			if ( $slider_1 || $slider_2 || $slider_3 || $slider_4 || $slider_5 ) :
				echo '<div class="slider owl-carousel">';

					if ( $slider_1 ) {
						echo '<div class="slider-item">';
							echo wp_get_attachment_image( absint( $slider_1 ), 'shopy-slider' );
							echo '<span class="overlay">';
								echo '<span class="overlay-text">';
									echo '<span class="slider-text">' . esc_attr( $slider_1_text ) . '</span>';
									echo '<a class="slider-link" href="' . esc_url( $slider_1_url ) . '">' . __( 'Shop Now', 'shopy' ) . '</a>';
								echo '</span>';
							echo '</span>';
						echo '</div>';
					}

					if ( $slider_2 ) {
						echo '<div class="slider-item">';
							echo wp_get_attachment_image( absint( $slider_2 ), 'shopy-slider' );
							echo '<span class="overlay">';
								echo '<span class="overlay-text">';
									echo '<span class="slider-text">' . esc_attr( $slider_2_text ) . '</span>';
									echo '<a class="slider-link" href="' . esc_url( $slider_2_url ) . '">' . __( 'Shop Now', 'shopy' ) . '</a>';
								echo '</span>';
							echo '</span>';
						echo '</div>';
					}

					if ( $slider_3 ) {
						echo '<div class="slider-item">';
							echo wp_get_attachment_image( absint( $slider_3 ), 'shopy-slider' );
							echo '<span class="overlay">';
								echo '<span class="overlay-text">';
									echo '<span class="slider-text">' . esc_attr( $slider_3_text ) . '</span>';
									echo '<a class="slider-link" href="' . esc_url( $slider_3_url ) . '">' . __( 'Shop Now', 'shopy' ) . '</a>';
								echo '</span>';
							echo '</span>';
						echo '</div>';
					}

					if ( $slider_4 ) {
						echo '<div class="slider-item">';
							echo wp_get_attachment_image( absint( $slider_4 ), 'shopy-slider' );
							echo '<span class="overlay">';
								echo '<span class="overlay-text">';
									echo '<span class="slider-text">' . esc_attr( $slider_4_text ) . '</span>';
									echo '<a class="slider-link" href="' . esc_url( $slider_4_url ) . '">' . __( 'Shop Now', 'shopy' ) . '</a>';
								echo '</span>';
							echo '</span>';
						echo '</div>';
					}

					if ( $slider_5 ) {
						echo '<div class="slider-item">';
							echo wp_get_attachment_image( absint( $slider_5 ), 'shopy-slider' );
							echo '<span class="overlay">';
								echo '<span class="overlay-text">';
									echo '<span class="slider-text">' . esc_attr( $slider_5_text ) . '</span>';
									echo '<a class="slider-link" href="' . esc_url( $slider_5_url ) . '">' . __( 'Shop Now', 'shopy' ) . '</a>';
								echo '</span>';
							echo '</span>';
						echo '</div>';
					}

				echo '</div>';
			endif;

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) { ?>

		<p><?php printf( __( 'Please set up the Slider on %1$sCustomizer%2$s', 'shopy' ), '<a href="' . esc_url( admin_url( 'customize.php' ) ) . '">', '</a>' ); ?></p>

	<?php

	}

}