<?php
/**
 * Custom template tags used to integrate this theme with WooCommerce.
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'shopy_header_cart' ) ) :
/**
 * Display Header Cart
 * 
 * @since  1.0.0
 */
function shopy_header_cart() { 

	$prefix = 'shopy-';
	$show   = shopy_mod( $prefix . 'header-cart' );
	if ( $show ) :
	?>
		<div class="header-cart">
			<span>
				<?php shopy_cart_link(); ?>
			</span>
			<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
		</div>
	<?php
	endif;
}
endif;

if ( ! function_exists( 'shopy_cart_link' ) ) :
/**
 * Cart link
 * 
 * @since  1.0.0
 */
function shopy_cart_link() { ?>
	<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'shopy' ); ?>">
		<span class="total"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></span>
		<i class="fa fa-shopping-cart"></i>
		<span class="count"><?php echo wp_kses_data( WC()->cart->get_cart_contents_count() );?></span>
	</a>
	<?php
}
endif;

if ( ! function_exists( 'shopy_before_content' ) ) :
/**
 * Before Content
 * Wraps all WooCommerce content in wrappers which match the theme markup
 * 
 * @since   1.0.0
 */
function shopy_before_content() {
	?>
	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">
		<?php
}
endif;

if ( ! function_exists( 'shopy_after_content' ) ) :
/**
 * After Content
 * Closes the wrapping divs
 * 
 * @since   1.0.0
 */
function shopy_after_content() {
	?>
		</main><!-- #main -->
	</div><!-- #primary -->

	<?php
}
endif;

if ( ! function_exists( 'shopy_sorting_wrapper' ) ) :
/**
 * Sorting wrapper
 * 
 * @since   1.0.0
 */
function shopy_sorting_wrapper() {
	echo '<div class="shopy-sorting">';
}
endif;

if ( ! function_exists( 'shopy_sorting_wrapper_close' ) ) :
/**
 * Sorting wrapper close
 * 
 * @since   1.0.0
 */
function shopy_sorting_wrapper_close() {
	echo '</div>';
}
endif;

if ( ! function_exists( 'storefront_upsell_display' ) ) :
/**
 * Upsells
 * Replace the default upsell function with our own which displays the correct number product columns
 * 
 * @since   1.0.0
 */
function shopy_upsell_display() {
	woocommerce_upsell_display( -1, 3 );
}
endif;

if ( ! function_exists( 'shopy_add_to_wishlist' ) ) :
/**
 * Add to wishlist
 * 
 * @since   1.0.0
 */
function shopy_add_to_wishlist() {
	
	if ( class_exists( 'YITH_WCWL_Shortcode' ) ) {
		echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
	}

}
endif;

if ( ! function_exists( 'shopy_payment_method' ) ) :
/**
 * Payment method image
 * 
 * @since   1.0.0
 */
function shopy_payment_method() {
	
	// Prefix
	$prefix = 'shopy-';

	// Get the data from Customizer
	$img = shopy_mod( $prefix . 'payment-method' );

	if ( $img ) {
		echo '<div class="payment-method">' . wp_get_attachment_image( $img, 'full' ) . '</div>';
	}

}
endif;