<?php
/**
 * WooCommerce compatibility and custom functions
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Define WooCommerce image sizes.
 *
 * @since  1.0.0
 */
function shopy_woocommerce_image_dimensions() {
	global $pagenow;
 
	if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
		return;
	}

  	$catalog = array(
		'width' 	=> '400',
		'height'	=> '400',
		'crop'		=> 1
	);
	$single = array(
		'width' 	=> '600',
		'height'	=> '600',
		'crop'		=> 1
	);
	$thumbnail = array(
		'width' 	=> '120',
		'height'	=> '120',
		'crop'		=> 0
	);

	// Image sizes
	update_option( 'shop_catalog_image_size', $catalog );     // Product category thumbs
	update_option( 'shop_single_image_size', $single );       // Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); // Image gallery thumbs

}
add_action( 'after_switch_theme', 'shopy_woocommerce_image_dimensions', 1 );

/**
 * Modifies the theme layout on woocommerce pages.
 *
 * @since  1.0.0
 */
function shopy_add_to_cart_link( $product ) {
	global $product;

	$add_to_cart = sprintf( '<a href="%s" rel="nofollow" data-product_id="%s" data-product_sku="%s" data-quantity="%s" class="button %s product_type_%s">%s</a>',
		esc_url( $product->add_to_cart_url() ),
		esc_attr( $product->id ),
		esc_attr( $product->get_sku() ),
		esc_attr( isset( $quantity ) ? $quantity : 1 ),
		$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
		esc_attr( $product->product_type ),
		'<i class="fa fa-shopping-cart"></i>'
	);
	
	return $add_to_cart;
}
add_filter( 'woocommerce_loop_add_to_cart_link', 'shopy_add_to_cart_link', 10 );

/**
 * Cart Fragments
 * Ensure cart contents update when products are added to the cart via AJAX
 *
 * @since  1.0.0
 */
function shopy_cart_link_fragment( $fragments ) {
	global $woocommerce;

	ob_start();

	shopy_cart_link();

	$fragments['a.cart-contents'] = ob_get_clean();

	return $fragments;
}
if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '2.3', '>=' ) ) {
	add_filter( 'woocommerce_add_to_cart_fragments', 'shopy_cart_link_fragment' );
} else {
	add_filter( 'add_to_cart_fragments', 'shopy_cart_link_fragment' );
}

/**
 * Related Products Args
 * 
 * @since 1.0.0
 */
function shopy_related_products_args( $args ) {
	$args = apply_filters( 'shopy_related_products_args', array(
		'posts_per_page' => 3,
		'columns'        => 3,
	) );

	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'shopy_related_products_args' );

/**
 * Product gallery thumnail columns.
 * 
 * @since  1.0.0
 */
function shopy_thumbnail_columns() {
	return intval( apply_filters( 'shopy_product_thumbnail_columns', 4 ) );
}
add_filter( 'woocommerce_product_thumbnails_columns', 'shopy_thumbnail_columns' );

/**
 * Products per page
 * 
 * @since  1.0.0
 */
function shopy_products_per_page() {
	return intval( apply_filters( 'shopy_products_per_page', 12 ) );
}
add_filter( 'loop_shop_per_page', 'shopy_products_per_page' );

/**
 * Default loop columns on product archives
 * 
 * @since  1.0.0
 */
function shopy_loop_columns() {
	return apply_filters( 'shopy_loop_columns', 3 ); // 3 products per row
}
add_filter( 'loop_shop_columns', 'shopy_loop_columns' );

/**
 * Limit cross sells to 2
 *
 * @since  1.0.0
 */
function shopy_cross_sells_limit() {
	return 2;
}
add_filter( 'woocommerce_cross_sells_total', 'shopy_cross_sells_limit' );

/**
 * Remove WooCommerce Grid/List view extensions
 *
 * @since  1.0.0
 */
function shopy_remove_gridlist_styles() {
    wp_dequeue_style( 'grid-list-button' );
}
add_action( 'wp_enqueue_scripts', 'shopy_remove_gridlist_styles', 30 );

/**
 * WooCommerce pages layout
 *
 * @since  1.0.0
 */
function shopy_woo_layouts( $layout ) {

	if ( is_woocommerce() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '2c-l';
		}
	}

	if ( is_cart() || is_checkout() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'shopy_woo_layouts', 15 );